@@ -7,7 +7,6 @@ import numpy as np
 import pandas as pd
 from addict import Dict
 from dateutil.parser import parse
-
 from sangreal_bt.commons import Commons
 from sangreal_bt.datafeed.datafeed import DataBase
 from sangreal_bt.stats.stats import Stats
@@ -120,8 +119,8 @@ class Strategy:
         _s0 = signal_asset.sum(axis=1)
         _s1 = signal_future.sum(axis=1)
         # 加一个常数 防止正好权重为0
-        signal_asset['cash'] = 1 * np.sign(_s0+1e-8) - _s0
-        signal_future['cash'] = 1 * np.sign(_s1+1e-8) - _s1
+        signal_asset['cash'] = 1 * np.sign(_s0 + 1e-8) - _s0
+        signal_future['cash'] = 1 * np.sign(_s1 + 1e-8) - _s1
 
         # 第二天开盘价买入
         if self.matching_type == 'next_bar':
@@ -244,8 +243,7 @@ class Strategy:
         signal_all = signal_all / weight_factor
 
         # 归一化
-        signal_all = signal_all.div(
-            signal_all.sum(axis=1).abs(), axis='index')
+        signal_all = signal_all.div(signal_all.sum(axis=1).abs(), axis='index')
 
         if not signal.empty:
             # 最后一期持仓
@@ -401,14 +399,16 @@ class Strategy:
         # 保存输出的净值
         self.result.nav = ret_all
         # 保存最新持仓
-        self.result.hold = hold_asset.append(hold_future)
+        _hold = hold_asset.append(hold_future)
+        _hold = _hold[_hold['stockid'] != 'cash'].copy()
+        self.result.hold = _hold.copy()
         # 保存基准
         self.result.benchmark = self.benchmark
         # 保存换手率
         delta = len(ret_all)
         self.result.stats.turnover = self._get_turnover(
-            self._signal['asset'], delta) + self._get_turnover(
-                self._signal['future'], delta)
+            self._signal['asset'].drop(['cash'], axis=1, errors='ignore'), delta) + self._get_turnover(
+                self._signal['future'].drop(['cash'], axis=1, errors='ignore'), delta)
         if stats:
             # 增加其他属性
             s = Stats(ret_all['hedge'].pct_change().fillna(0),
